MethodChannelOktaOidcPlus class
An implementation of OktaOidcPlusPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- OktaOidcPlusPlatform
- MethodChannelOktaOidcPlus
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized ↔ bool
-
Tracks whether Okta client has been initialized.
getter/setter pair
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAccessToken(
) → Future< Map?> -
Fetches current valid access token or refreshes it.
override
-
getUserProfile(
) → Future -
Fetches authenticated user profile claims.
override
-
initOkta(
Map< String, dynamic> ? oktaConfig) → Future<bool?> -
Initializes the Okta OIDC client with configuration parameters.
override
-
login(
) → Future< Map?> -
Initiates web-based OIDC sign-in flow.
override
-
logout(
) → Future< bool?> -
Logs out the user and revokes session tokens.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
Initiates social login flow with specified provider parameters.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited