OktaOidcPlusPlatform class abstract
The interface that platform implementations of OktaOidcPlusPlatform must implement.
- Inheritance
-
- Object
- PlatformInterface
- OktaOidcPlusPlatform
- Implementers
Constructors
- OktaOidcPlusPlatform()
- Constructs a OktaOidcPlusPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAccessToken(
) → Future< Map?> - Fetches current valid access token or refreshes it.
-
getUserProfile(
) → Future - Fetches authenticated user profile claims.
-
initOkta(
Map< String, dynamic> ? oktaConfig) → Future<bool?> - Initializes the Okta OIDC client with configuration parameters.
-
login(
) → Future< Map?> - Initiates web-based OIDC sign-in flow.
-
logout(
) → Future< bool?> - Logs out the user and revokes session tokens.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
- Initiates social login flow with specified provider parameters.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ OktaOidcPlusPlatform
-
The default instance of OktaOidcPlusPlatform to use.
getter/setter pair